@@ -4,6 +4,8 @@ KB부동산 데이터 API
 import requests
 import pandas as pd
 
+requests.packages.urllib3.disable_warnings()
+
 
 class Kbland:
 
@@ -92,7 +94,7 @@ class Kbland:
         }
         params.update(kwargs)
         try:
-            res = requests.get(url, params=params)
+            res = requests.get(url, params=params, verify=False)
             data = res.json()['dataBody']['data']
         except Exception as e:
             print(e)
@@ -141,7 +143,7 @@ class Kbland:
         params = {}
         params.update(kwargs)
         try:
-            res = requests.get(url, params=params)
+            res = requests.get(url, params=params, verify=False)
             data = res.json()['dataBody']['data']
         except Exception as e:
             print(e)
@@ -190,7 +192,7 @@ class Kbland:
         params = {}
         params.update(kwargs)
         try:
-            res = requests.get(url, params=params)
+            res = requests.get(url, params=params, verify=False)
             data = res.json()['dataBody']['data']
         except Exception as e:
             print(e)
@@ -257,7 +259,7 @@ class Kbland:
         }
         params.update(kwargs)
         try:
-            res = requests.get(url, params=params)
+            res = requests.get(url, params=params, verify=False)
             data = res.json()['dataBody']['data']
         except Exception as e:
             print(e)
@@ -319,7 +321,7 @@ class Kbland:
         }
         params.update(kwargs)
         try:
-            res = requests.get(url, params=params)
+            res = requests.get(url, params=params, verify=False)
             data = res.json()['dataBody']['data']
         except Exception as e:
             print(e)
@@ -366,7 +368,7 @@ class Kbland:
         params = {}
         params.update(kwargs)
         try:
-            res = requests.get(url, params=params)
+            res = requests.get(url, params=params, verify=False)
             data = res.json()['dataBody']['data']
         except Exception as e:
             print(e)
@@ -430,7 +432,7 @@ class Kbland:
         }
         params.update(kwargs)
         try:
-            res = requests.get(url, params=params)
+            res = requests.get(url, params=params, verify=False)
             data = res.json()['dataBody']['data']
         except Exception as e:
             print(e)
@@ -514,7 +516,7 @@ class Kbland:
         }
         params.update(kwargs)
         try:
-            res = requests.get(url, params=params)
+            res = requests.get(url, params=params, verify=False)
             data = res.json()['dataBody']['data']
         except Exception as e:
             print(e)
@@ -585,7 +587,7 @@ class Kbland:
         }
         params.update(kwargs)
         try:
-            res = requests.get(url, params=params)
+            res = requests.get(url, params=params, verify=False)
             data = res.json()['dataBody']['data']
         except Exception as e:
             print(e)
@@ -647,7 +649,7 @@ class Kbland:
         }
         params.update(kwargs)
         try:
-            res = requests.get(url, params=params)
+            res = requests.get(url, params=params, verify=False)
             data = res.json()['dataBody']['data']
         except Exception as e:
             print(e)
@@ -709,7 +711,7 @@ class Kbland:
         }
         params.update(kwargs)
         try:
-            res = requests.get(url, params=params)
+            res = requests.get(url, params=params, verify=False)
             data = res.json()['dataBody']['data']
         except Exception as e:
             print(e)
@@ -762,7 +764,7 @@ class Kbland:
         }
         params.update(kwargs)
         try:
-            res = requests.get(url, params=params)
+            res = requests.get(url, params=params, verify=False)
             data = res.json()['dataBody']['data']
         except Exception as e:
             print(e)
@@ -832,7 +834,7 @@ class Kbland:
         }
         params.update(kwargs)
         try:
-            res = requests.get(url, params=params)
+            res = requests.get(url, params=params, verify=False)
             data = res.json()['dataBody']['data']
         except Exception as e:
             print(e)
@@ -890,7 +892,7 @@ class Kbland:
         }
         params.update(kwargs)
         try:
-            res = requests.get(url, params=params)
+            res = requests.get(url, params=params, verify=False)
             data = res.json()['dataBody']['data']
         except Exception as e:
             print(e)
@@ -944,7 +946,7 @@ class Kbland:
         params = {}
         params.update(kwargs)
         try:
-            res = requests.get(url, params=params)
+            res = requests.get(url, params=params, verify=False)
             data = res.json()['dataBody']['data']
         except Exception as e:
             print(e)
@@ -990,7 +992,7 @@ class Kbland:
         params = {}
         params.update(kwargs)
         try:
-            res = requests.get(url, params=params)
+            res = requests.get(url, params=params, verify=False)
             data = res.json()['dataBody']['data']
         except Exception as e:
             print(e)
@@ -1018,7 +1020,7 @@ class Kbland:
         params = {}
         params.update(kwargs)
         try:
-            res = requests.get(url, params=params)
+            res = requests.get(url, params=params, verify=False)
             data = res.json()['dataBody']['data']
         except Exception as e:
             print(e)
@@ -1057,7 +1059,7 @@ class Kbland:
         params = {}
         params.update(kwargs)
         try:
-            res = requests.get(url, params=params)
+            res = requests.get(url, params=params, verify=False)
             data = res.json()['dataBody']['data']
         except Exception as e:
             print(e)
